=========================================
Configure the Propertyshelf MLS Embedding
=========================================

Before you can start embedding properties and developments into your Plone site you have to connect to the MLS.
But don't worry, this only needs to be done once.

To change the global embedding settings:

#. Click on your username in the *personal tools menu* and select **Site Setup**
#. Click the **Propertyshelf MLS Embedding** item in the *Add-on Configuration* section

The configuration is split into 5 parts:

- Base Settings
- UI Settings
- Contact Information
- Caching Settings
- Usage Overview


MLS Base Settings
=================

The base settings define the connection settings to your MLS.
You need to add the *URL* to the MLS, as well as your *Agency ID* and your *API Key*.

.. note::

   If you don't have an API Key yet, please ask your MLS Administrator for one.

.. figure:: ../_images/controlpanel_base.png

   Propertyshelf MLS Embedding: Base Settings


MLS UI Settings
===============

The ui settings define the look and feel of the MLS Embedding.

.. figure:: ../_images/controlpanel_ui.png

   Propertyshelf MLS Embedding: UI Settings



MLS Contact Info Settings
=========================

Here you can customize the contact information for listings and developments.

.. figure:: ../_images/controlpanel_contact_info_default.png

   Propertyshelf MLS Embedding: Contact Information Settings


.. figure:: ../_images/controlpanel_contact_info_agency.png

   Propertyshelf MLS Embedding: Agency Contact Information Settings


.. figure:: ../_images/controlpanel_contact_info_agent.png

   Propertyshelf MLS Embedding: Agent Contact Information Settings


MLS Caching Settings
====================

With the caching settings you can define how often updates should be fetched from the configured MLS.

.. figure:: ../_images/controlpanel_caching.png

   Propertyshelf MLS Embedding: Caching Settings


MLS Usage Overview
==================

The usage overview gives you an overview about the MLS embedding on your site.
You can see all activated embedding items in one place.

.. figure:: ../_images/controlpanel_usage.png

   Propertyshelf MLS Embedding: Usage Overview
